#
# spec file for package python-pytest-mypy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-mypy
Version:        1.0.1
Release:        1.1
Summary:        Mypy static type checker plugin for Pytest
License:        MIT
URL:            https://github.com/realpython/pytest-mypy
Source:         https://files.pythonhosted.org/packages/source/p/pytest-mypy/pytest_mypy-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm >= 3.5}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 19.0
Requires:       python-filelock >= 3.0
Requires:       python-mypy >= 1.0
Requires:       python-pytest >= 7
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module attrs >= 19.0}
BuildRequires:  %{python_module filelock >= 3.0}
BuildRequires:  %{python_module mypy >= 1.0}
BuildRequires:  %{python_module pexpect}
BuildRequires:  %{python_module pytest >= 7}
BuildRequires:  %{python_module pytest-xdist}

# /SECTION
%python_subpackages

%description
Mypy static type checker plugin for Pytest.

%prep
%autosetup -p1 -n pytest_mypy-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# encoding_warnings: 3 unexpected extra warnings
# test_looponfail: timeout error
%pytest -k 'not (test_mypy_encoding_warnings or test_looponfail)'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pytest_mypy
%{python_sitelib}/pytest[-_]mypy-%{version}.dist-info

%changelog
* Wed May  7 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.1:
  * Catch OSErrors when parsing mypy error paths
  * Add test_pyproject_toml
  * Drop Python 3.6 support and use PEP 621 metadata
  * Test with mypy 1.x and fewer old versions
  * Prevent AttributeError in pytest_terminal_summary
  * Add support for Python 3.12
  * Add support for pytest 8
  * Ensure expected versions are installed while testing
  * Require mypy >= 1.0
  * Generalize MypyResults.from_mypy
  * Require Pytest 7+
  * Use config.stash to store the results path
  * Replace attrs with dataclasses
  * Create MypyConfigStash
  * Refactor xdist integration
  * Add strict type-checking
  * Add --mypy-no-status-check
  * Add --mypy-xfail
  * Move results path cleanup to pytest_unconfigure
  * Remove MypyWarning
  * Replace MypyItem.MARKER with item_marker
  * Create MypyCollectionPlugin
  * Add support for Python 3.13
  * Drop support for Python 3.7
  * Resolve PYTHONWARNDEFAULTENCODING warnings
  * Make MypyResults line-based
  * Add test_name_formatter
  * Add --mypy-report-style
- Switch to pyproject macros.
- Drop patch indirect-test-new-mypy.patch, no longer required.
* Thu Sep 26 2024 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Fixed %%{?sle15_python_module_pythons}
* Wed Feb  8 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.10.3:
  * Stop failing if mypy only produces notes.
  * Update and loosen [build-system] requirements.
  * Work around python/mypy#14042.
  * Add support for Python 3.11.
* Sat Oct 15 2022 John Vandenberg <jayvdb@gmail.com>
- Update URL
- Update to v0.10.0
  * Drop support for python<3.6
* Thu Aug 18 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update 0.9.1:
  * Add support for pytest 7.
  * Drop support for pytest<4.6.
  * Add --mypy-config-file.
- Drop patch 121-recent-mypy.patch, included upstream.
- Add patch indirect-test-new-mypy.patch:
  * Fix failing test with new mypy.
* Mon Jan 10 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.8.1:
  - Implement MypyItem.collect for pytest < 6.0
  - Update dev deps and extend static checks
  - Test with mypy 0.8
- Add 121-recent-mypy.patch to make the test suite pass with the
  recent mypy.
* Tue Feb 23 2021 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v0.8.0:
  - Stop injecting MypyStatusItem in
    pytest_collection_modifyitems to fix --looponfail
  - Add support for Python 3.9
  - Create MypyResults
* Mon Sep  7 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.7.0
* Tue Dec 10 2019 Todd R <toddrme2178@gmail.com>
- initial version v0.4.2
